# Inspector | Code Execution Monitoring Tool

Simple code execution monitoring for Python applications.

## Requirements

- Python >= 3.x

## Abstract
This library will allow Python developers to connect their applications to the Code Execution Monitoring tool Inspector.

The development is in progress under the direct management of the Inspector team. This is not a community project.

## License
This library is licensed under the [MIT](LICENSE) license.